@@ -123,7 +123,6 @@ SKIPPED_IMAGES = {
         "monasca-thresh",
         "nova-mksproxy",
         "novajoin-base",
-        "octavia-base",
         # There is no qdrouterd package for ubuntu bionic
         "qdrouterd",
         "searchlight-base",
@@ -199,14 +198,17 @@ SKIPPED_IMAGES = {
         "monasca-thresh",
         "nova-mksproxy",
         "ovsdpdk",
+        "rsyslog",
         "searchlight-base",
         "solum-base",
+        "tripleoclient",
         "vmtp",
         "zun-base"
     ],
     'oraclelinux+source': [
         "bifrost-base",
         "ovsdpdk",
+        "rsyslog",
         "tripleoclient",
         # TODO(jeffrey4l): remove tripleo-ui when following bug is fixed
         # https://bugs.launchpad.net/tripleo/+bug/1744215
@@ -318,6 +320,11 @@ class PushIntoQueueTask(task.Task):
         self.success = True
 
 
+class PushError(Exception):
+    """Raised when there is a problem with pushing image to repository."""
+    pass
+
+
 class PushTask(DockerTask):
     """Task that pushes an image to a docker repository."""
 
@@ -341,6 +348,9 @@ class PushTask(DockerTask):
                                   ' have the correct privileges to run Docker'
                                   ' (root)')
             image.status = STATUS_CONNECTION_ERROR
+        except PushError as exception:
+            self.logger.error(exception)
+            image.status = STATUS_PUSH_ERROR
         except Exception:
             self.logger.exception('Unknown error when pushing')
             image.status = STATUS_PUSH_ERROR
@@ -365,8 +375,10 @@ class PushTask(DockerTask):
             if 'stream' in response:
                 self.logger.info(response['stream'])
             elif 'errorDetail' in response:
-                image.status = STATUS_ERROR
-                self.logger.error(response['errorDetail']['message'])
+                raise PushError(response['errorDetail']['message'])
+
+        # Reset any previous errors.
+        image.status = STATUS_BUILT
 
 
 class BuildTask(DockerTask):
